@@ -101,6 +101,8 @@ public:
         needsUpdateUniqueHash(false),
         idle(false),
         scanSuspended(0),
+        deferFileScanning(false),
+        finishScanAllowed(true),
         continueInitialization(false),
         continueScan(false),
         continuePartialScan(false),
@@ -111,7 +113,8 @@ public:
         progressDialog(0),
         splash(0),
         advice(ScanController::Success),
-        needTotalFiles(false)
+        needTotalFiles(false),
+        totalFilesToScan(0)
     {
     }
 
@@ -125,6 +128,10 @@ public:
 
     QStringList               scanTasks;
 
+    QStringList               completeScanDeferredAlbums;
+    bool                      deferFileScanning;
+    bool                      finishScanAllowed;
+
     QMutex                    mutex;
     QWaitCondition            condVar;
 
@@ -157,6 +164,7 @@ public:
     ScanController::Advice    advice;
 
     bool                      needTotalFiles;
+    int                       totalFilesToScan;
 
 public:
 
@@ -302,11 +310,11 @@ ScanController::ScanController()
             this, SLOT(slotRelaxedScanning()));
 
     // interthread connections
-    connect(this, SIGNAL(errorFromInitialization(const QString&)),
-            this, SLOT(slotErrorFromInitialization(const QString&)));
+    connect(this, SIGNAL(errorFromInitialization(QString)),
+            this, SLOT(slotErrorFromInitialization(QString)));
 
-    connect(this, SIGNAL(progressFromInitialization(const QString&, int)),
-            this, SLOT(slotProgressFromInitialization(const QString&, int)));
+    connect(this, SIGNAL(progressFromInitialization(QString,int)),
+            this, SLOT(slotProgressFromInitialization(QString,int)));
 
     // start thread
     d->running = true;
@@ -416,7 +424,19 @@ ScanController::Advice ScanController::databaseInitialization()
     return d->advice;
 }
 
-void ScanController::completeCollectionScan(SplashScreen* splash)
+void ScanController::completeCollectionScanDeferFiles(SplashScreen* splash)
+{
+    completeCollectionScan(splash, true);
+}
+
+void ScanController::allowToScanDeferredFiles()
+{
+    QMutexLocker lock(&d->mutex);
+    d->finishScanAllowed = true;
+    d->condVar.wakeAll();
+}
+
+void ScanController::completeCollectionScan(SplashScreen* splash, bool defer)
 {
     d->splash         = splash;
     createProgressDialog();
@@ -427,6 +447,7 @@ void ScanController::completeCollectionScan(SplashScreen* splash)
     {
         QMutexLocker lock(&d->mutex);
         d->needsCompleteScan = true;
+        d->deferFileScanning = defer;
         d->condVar.wakeAll();
     }
     // loop is quit by signal
@@ -585,6 +606,8 @@ void ScanController::run()
     {
         bool doInit             = false;
         bool doScan             = false;
+        bool doScanDeferred     = false;
+        bool doFinishScan       = false;
         bool doPartialScan      = false;
         bool doUpdateUniqueHash = false;
 
@@ -601,12 +624,18 @@ void ScanController::run()
             {
                 d->needsCompleteScan = false;
                 doScan               = true;
+                doScanDeferred       = d->deferFileScanning;
             }
             else if (d->needsUpdateUniqueHash)
             {
                 d->needsUpdateUniqueHash = false;
                 doUpdateUniqueHash       = true;
             }
+            else if (!d->completeScanDeferredAlbums.isEmpty() && d->finishScanAllowed && !d->scanSuspended)
+            {
+                // d->completeScanDeferredAlbums is only accessed from the thread, no need to copy
+                doFinishScan             = true;
+            }
             else if (!d->scanTasks.isEmpty() && !d->scanSuspended)
             {
                 doPartialScan = true;
@@ -638,14 +667,51 @@ void ScanController::run()
         {
             CollectionScanner scanner;
             connectCollectionScanner(&scanner);
+
             scanner.setNeedFileCount(d->needTotalFiles);
+            scanner.setDeferredFileScanning(doScanDeferred);
+
             scanner.recordHints(d->albumHints);
             scanner.recordHints(d->itemHints);
             scanner.recordHints(d->itemChangeHints);
+
             SimpleCollectionScannerObserver observer(&d->continueScan);
             scanner.setObserver(&observer);
+
             scanner.completeScan();
+
             emit completeScanDone();
+            if (doScanDeferred)
+            {
+                d->completeScanDeferredAlbums = scanner.deferredAlbumPaths();
+                d->finishScanAllowed = false;
+            }
+        }
+        else if (doFinishScan)
+        {
+            if (d->completeScanDeferredAlbums.isEmpty())
+            {
+                continue;
+            }
+            CollectionScanner scanner;
+            connectCollectionScanner(&scanner);
+
+            emit collectionScanStarted(i18nc("@info:status", "Scanning collection"));
+            //TODO: reconsider performance
+            scanner.setNeedFileCount(true);//d->needTotalFiles);
+
+            scanner.recordHints(d->albumHints);
+            scanner.recordHints(d->itemHints);
+            scanner.recordHints(d->itemChangeHints);
+
+            SimpleCollectionScannerObserver observer(&d->continueScan);
+            scanner.setObserver(&observer);
+
+            scanner.finishCompleteScan(d->completeScanDeferredAlbums);
+
+            d->completeScanDeferredAlbums.clear();
+            emit completeScanDone();
+            emit collectionScanFinished();
         }
         else if (doPartialScan)
         {
@@ -681,14 +747,14 @@ void ScanController::connectCollectionScanner(CollectionScanner* scanner)
     connect(scanner, SIGNAL(totalFilesToScan(int)),
             this, SLOT(slotTotalFilesToScan(int)));
 
-    connect(scanner, SIGNAL(startScanningAlbum(const QString&, const QString&)),
-            this, SLOT(slotStartScanningAlbum(const QString&, const QString&)));
+    connect(scanner, SIGNAL(startScanningAlbum(QString,QString)),
+            this, SLOT(slotStartScanningAlbum(QString,QString)));
 
     connect(scanner, SIGNAL(scannedFiles(int)),
             this, SLOT(slotScannedFiles(int)));
 
-    connect(scanner, SIGNAL(startScanningAlbumRoot(const QString&)),
-            this, SLOT(slotStartScanningAlbumRoot(const QString&)));
+    connect(scanner, SIGNAL(startScanningAlbumRoot(QString)),
+            this, SLOT(slotStartScanningAlbumRoot(QString)));
 
     connect(scanner, SIGNAL(startScanningForStaleAlbums()),
             this, SLOT(slotStartScanningForStaleAlbums()));
@@ -703,10 +769,12 @@ void ScanController::slotTotalFilesToScan(int count)
     {
         d->progressDialog->incrementMaximum(count);
     }
+    d->totalFilesToScan = count;
 }
 
 void ScanController::slotStartCompleteScan()
 {
+    d->totalFilesToScan = 0;
     slotTriggerShowProgressDialog();
 
     QString message = i18n("Preparing collection scan");
@@ -738,6 +806,10 @@ void ScanController::slotScannedFiles(int filesScanned)
     {
         d->progressDialog->advance(filesScanned);
     }
+    if (d->totalFilesToScan)
+    {
+        emit scanningProgress(double(filesScanned) / double(d->totalFilesToScan));
+    }
 }
 
 void ScanController::slotStartScanningAlbumRoot(const QString& albumRoot)
@@ -985,8 +1057,8 @@ ScanControllerLoadingCacheFileWatch::ScanControllerLoadingCacheFileWatch()
     DatabaseWatch* dbwatch = DatabaseAccess::databaseWatch();
 
     // we opt for a queued connection to make stuff a bit relaxed
-    connect(dbwatch, SIGNAL(imageChange(const ImageChangeset&)),
-            this, SLOT(slotImageChanged(const ImageChangeset&)),
+    connect(dbwatch, SIGNAL(imageChange(ImageChangeset)),
+            this, SLOT(slotImageChanged(ImageChangeset)),
             Qt::QueuedConnection);
 }
 
