@@ -799,7 +799,7 @@ void ImageGuideWidget::setPaintColor(const QColor& color)
 void ImageGuideWidget::setMaskEnabled(bool enabled)
 {
     d->enableDrawMask = enabled;
-    updateMaskCursor();
+    unsetCursor();
     updatePreview();
 }
 
@@ -854,4 +854,14 @@ void ImageGuideWidget::updateMaskCursor()
     d->maskCursor = QCursor(pix);
 }
 
+void ImageGuideWidget::setMaskCursor()
+{
+    if (d->enableDrawMask)
+    {
+        updateMaskCursor();
+        setCursor(d->maskCursor);
+        updatePreview();
+    }
+}
+
 }  // namespace Digikam
