@@ -59,7 +59,7 @@
 // Local includes
 
 #include "albumsettings.h"
-#include "config-digikam.h"
+#include <config-digikam.h>
 #include "metadatapanel.h"
 #include "metadatasettings.h"
 
@@ -164,8 +164,8 @@ SetupMetadata::SetupMetadata(QWidget* parent)
                                            "You can set template values to Template setup page."));
 
     d->saveCommentsBox = new QCheckBox(commonGroup);
-    d->saveCommentsBox->setText(i18n("&Save image captions in metadata embedded in files "));
-    d->saveCommentsBox->setWhatsThis( i18n("Turn on this option to store image captions "
+    d->saveCommentsBox->setText(i18n("&Save image captions and title in metadata embedded in files "));
+    d->saveCommentsBox->setWhatsThis( i18n("Turn on this option to store image caption and title "
                                            "in the JFIF Comment section, the EXIF tag, the XMP tag, "
                                            "and the IPTC tag."));
 
@@ -201,7 +201,7 @@ SetupMetadata::SetupMetadata(QWidget* parent)
     d->updateFileTimeStampBox->setWhatsThis( i18n("Turn on this option to update file timestamps when metadata are saved."));
 
     d->useXMPSidecarBox = new QCheckBox(commonGroup);
-    d->useXMPSidecarBox->setText(i18n("&Read metadata from XMP sidecar files"));
+    d->useXMPSidecarBox->setText(i18n("&Read metadata from XMP sidecar files (experimental)"));
     d->useXMPSidecarBox->setWhatsThis( i18n("Turn on this option to prefer metadata from XMP sidecar files when reading metadata."));
     d->useXMPSidecarBox->setEnabled(KExiv2::supportXmp());
 
