@@ -285,11 +285,11 @@ void FbTalker::doOAuth()
         url = KUrl( textbox->text() );
         QString fragment = url.fragment();
         kDebug() << "Split out the fragment from the URL: " << fragment;
-        QStringList params = fragment.split("&");
+        QStringList params = fragment.split('&');
         QList<QString>::iterator i = params.begin();
         while( i != params.end() )
         {
-            QStringList keyvalue = (*i).split("=");
+            QStringList keyvalue = (*i).split('=');
             if( keyvalue.size() == 2 )
             {
                 if( ! keyvalue[0].compare( "access_token" ) )
@@ -316,7 +316,7 @@ void FbTalker::doOAuth()
                     errorCode = keyvalue[1];
                 }
             }
-            i++;
+            ++i;
         }
         if( !m_accessToken.isEmpty() && errorCode.isEmpty() && errorReason.isEmpty() )
         {
@@ -1238,7 +1238,7 @@ void FbTalker::parseResponseCreateAlbum(const QByteArray& data)
 
     kDebug() << "Parse Create Album response:" << endl << data;
 
-    QString newAlbumID  = QString();
+    QString newAlbumID;
     QDomElement docElem = doc.documentElement();
     if (docElem.tagName() == "photos_createAlbum_response")
     {
