@@ -422,7 +422,8 @@ QVariant AbstractPhoto::itemChange(GraphicsItemChange change, const QVariant & v
             d->m_pos = this->pos();
             emit changed();
             break;
-        default:;
+        default:
+            break;
     }
     return AbstractItemInterface::itemChange(change, value);
 }
